==> zio-aws-codeartifact_3-5.17.146.1-sources.jar: zio/aws/codeartifact/model/UpdateRepositoryResponse.scala <==
package zio.aws.codeartifact.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateRepositoryResponse(
    repository: Option[zio.aws.codeartifact.model.RepositoryDescription] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeartifact.model.UpdateRepositoryResponse = {
    import UpdateRepositoryResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeartifact.model.UpdateRepositoryResponse
      .builder()
      .optionallyWith(repository.map(value => value.buildAwsValue()))(
        _.repository
      )
      .build()
  }
  def asReadOnly: zio.aws.codeartifact.model.UpdateRepositoryResponse.ReadOnly =
    zio.aws.codeartifact.model.UpdateRepositoryResponse.wrap(buildAwsValue())
}
object UpdateRepositoryResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeartifact.model.UpdateRepositoryResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codeartifact.model.UpdateRepositoryResponse =
      zio.aws.codeartifact.model
        .UpdateRepositoryResponse(repository.map(value => value.asEditable))
    def repository
        : Option[zio.aws.codeartifact.model.RepositoryDescription.ReadOnly]
    def getRepository: ZIO[
      Any,
      AwsError,
      zio.aws.codeartifact.model.RepositoryDescription.ReadOnly
    ] = AwsError.unwrapOptionField("repository", repository)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeartifact.model.UpdateRepositoryResponse
  ) extends zio.aws.codeartifact.model.UpdateRepositoryResponse.ReadOnly {
    override val repository
        : Option[zio.aws.codeartifact.model.RepositoryDescription.ReadOnly] =
      scala
        .Option(impl.repository())
        .map(value =>
          zio.aws.codeartifact.model.RepositoryDescription.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeartifact.model.UpdateRepositoryResponse
  ): zio.aws.codeartifact.model.UpdateRepositoryResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-codeartifact_3-5.20.32.2-sources.jar: zio/aws/codeartifact/model/UpdateRepositoryResponse.scala <==
package zio.aws.codeartifact.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UpdateRepositoryResponse(
    repository: Optional[zio.aws.codeartifact.model.RepositoryDescription] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeartifact.model.UpdateRepositoryResponse = {
    import UpdateRepositoryResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeartifact.model.UpdateRepositoryResponse
      .builder()
      .optionallyWith(repository.map(value => value.buildAwsValue()))(
        _.repository
      )
      .build()
  }
  def asReadOnly: zio.aws.codeartifact.model.UpdateRepositoryResponse.ReadOnly =
    zio.aws.codeartifact.model.UpdateRepositoryResponse.wrap(buildAwsValue())
}
object UpdateRepositoryResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeartifact.model.UpdateRepositoryResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codeartifact.model.UpdateRepositoryResponse =
      zio.aws.codeartifact.model
        .UpdateRepositoryResponse(repository.map(value => value.asEditable))
    def repository
        : Optional[zio.aws.codeartifact.model.RepositoryDescription.ReadOnly]
    def getRepository: ZIO[
      Any,
      AwsError,
      zio.aws.codeartifact.model.RepositoryDescription.ReadOnly
    ] = AwsError.unwrapOptionField("repository", repository)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeartifact.model.UpdateRepositoryResponse
  ) extends zio.aws.codeartifact.model.UpdateRepositoryResponse.ReadOnly {
    override val repository
        : Optional[zio.aws.codeartifact.model.RepositoryDescription.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.repository())
        .map(value =>
          zio.aws.codeartifact.model.RepositoryDescription.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeartifact.model.UpdateRepositoryResponse
  ): zio.aws.codeartifact.model.UpdateRepositoryResponse.ReadOnly = new Wrapper(
    impl
  )
}
